.. currentmodule:: pysdic.imaging

pysdic.visualizer.visualize_qt_pyvista_linear_triangle_mesh_3d
===================================================================

.. autofunction:: pysdic.visualizer.visualize_qt_pyvista_linear_triangle_mesh_3d

